@@ -21,23 +21,23 @@
 */
 
 /*
- *  $Id: g2d_cogo.cpp,v 1.4 2002/12/18 13:33:24 cepek Exp $
+ *  $Id: g2d_cogo.cpp,v 1.6 2004/09/02 12:54:13 cepek Exp $
  */
 
-/**************************************************************
- * 2d coordinate geometry                                     *
- **************************************************************/
- 
-/*
- * In Median in all methods "Calculation" was added try / catch
- * block. Exceptions g2d_exc are sent by command throw for next
- * processing, for all other exceptions is returned state =
- * no_solution or number_of_solutions = -1. This change was motivated
- * by a bug, when in Median computaion of bearing for two identical
- * points failed.
- *
- * AC 2000.04.26 change median-0.7.5 / gamalib-0.9.57 
- * AC 2001.04.20 gamalib-1.1.61 */
+ /**************************************************************
+  * 2d coordinate geometry                                     *
+  **************************************************************/
+  
+ /*
+  * In Median in all methods "Calculation" was added try / catch
+  * block. Exceptions g2d_exc are sent by command throw for next
+  * processing, for all other exceptions is returned state =
+  * no_solution or number_of_solutions = -1. This change was motivated
+  * by a bug, when in Median computaion of bearing for two identical
+  * points failed.
+  *
+  * AC 2000.04.26 change median-0.7.5 / gamalib-0.9.57 
+  * AC 2001.04.20 gamalib-1.1.61 */
  
 #include <gamalib/local/median/g2d_cogo.h>
 #include <gamalib/local/median/g2d_exception.h>
@@ -57,16 +57,13 @@ namespace GaMaLib {
     h2 = dynamic_cast<Distance*>(m2);
     if(!(h1 && h2))
       throw g2d_exc("Distance_distance: wrong observation type");
-  };  
+  }  
 
   // ** computation: CHARAMZA, pp.127-130 **
 
   void Distance_distance::Calculation()
   {
     try {
-#ifdef PB_Debug
-      std::cout << "computing distance_distance....\n ";
-#endif
 
       number_of_solutions = 0;             // -1 when computation not done
       if(r1 == -1)
@@ -111,7 +108,7 @@ namespace GaMaLib {
         return;
       }
   
-  };  // void Distance_distance::Calculation
+  }  // void Distance_distance::Calculation
 
 
   //----------------------------------------------------------------
@@ -123,7 +120,7 @@ namespace GaMaLib {
     h2 = dynamic_cast<Direction*>(m2);
     if(!(h1 && h2))
       throw g2d_exc("Direction_direction: wrong observation type");
-  };
+  }
 
 
   // ** computation: CHARAMZA, pp.131-133 **
@@ -131,10 +128,6 @@ namespace GaMaLib {
   void Direction_direction::Calculation()
   {
     try {
-#ifdef PB_Debug
-      std::cout << "computing direction_direction...." << h1->from() 
-                << " and " << h2->from() << '\n';
-#endif
 
       number_of_solutions = 0;           // -1 when computation not done
       if(fabs(sin(h2->value())) < fabs(sin(h1->value())))
@@ -181,7 +174,7 @@ namespace GaMaLib {
         return;
       }
   
-  };  // void Direction_direction::Calculation
+  }  // void Direction_direction::Calculation
 
 
   // -----------------------------------------------------------------
@@ -198,16 +191,13 @@ namespace GaMaLib {
       };
     if(!(h1 && h2))
       throw g2d_exc("Direction_distance: wrong observation type");
-  }; 
+  } 
 
 
   // ** computation: CHARAMZA, pp.115-118 **
   void Direction_distance::Calculation()
   {
     try {
-#ifdef PB_Debug
-      std::cout << "computing direction_distance.... \n";
-#endif
 
       number_of_solutions = 0;    // -1 when computation not done
       const LocalPoint B1 = (*(SB->find(h1->from()))).second;
@@ -256,7 +246,7 @@ namespace GaMaLib {
         return;
       }
   
-  };  // void Direction_distance::Calculation()
+  }  // void Direction_distance::Calculation()
 
 
   //----------------------------------------------------------------
@@ -273,7 +263,7 @@ namespace GaMaLib {
       };
     if(!(h1 && h2))
       throw g2d_exc("Direction_angle: wrong observation type");
-  };
+  }
 
 
   // ** computation: CHARAMZA, p.142 **
@@ -281,9 +271,6 @@ namespace GaMaLib {
   void Direction_angle::Calculation()
   {
     try {
-#ifdef PB_Debug
-      std::cout << "computing direction_angle....\n";
-#endif
 
       number_of_solutions = 0;           // -1 when computation not done
       Circle K(h2,SB);
@@ -334,7 +321,7 @@ namespace GaMaLib {
         return;
       }
   
-  };  // void Direction_angle::Calculation()
+  }  // void Direction_angle::Calculation()
 
 
   //----------------------------------------------------------------
@@ -351,7 +338,7 @@ namespace GaMaLib {
       };
     if(!(h1 && h2))
       throw g2d_exc("Distance_angle: wrong observation type");
-  };
+  }
 
 
   // ** computiong: CHARAMZA, p.143 **
@@ -359,9 +346,6 @@ namespace GaMaLib {
   void Distance_angle::Calculation()
   {
     try {
-#ifdef PB_Debug
-      std::cout << "computing distance_angle....\n";
-#endif
 
       number_of_solutions = 0;           // -1 when computation not done
       Circle K(h2,SB);
@@ -416,7 +400,7 @@ namespace GaMaLib {
         return;
       }
   
-  };  // void Distance_angle::Calculation()
+  }  // void Distance_angle::Calculation()
 
 
   //-----------------------------------------------------------
@@ -428,7 +412,7 @@ namespace GaMaLib {
     h2 = dynamic_cast<Angle*>(m2);
     if(!(h1 && h2))
       throw g2d_exc("Angle_angle: wrong observation type");
-  };
+  }
 
 
   // ** computation: CHARAMZA, p.143 **
@@ -436,9 +420,6 @@ namespace GaMaLib {
   void Angle_angle::Calculation()
   {
     try {
-#ifdef PB_Debug
-      std::cout << "computing angle_angle....\n";
-#endif
 
       number_of_solutions = 0;           // -1 when computation not done
       Circle K1(h1,SB);
@@ -516,7 +497,7 @@ namespace GaMaLib {
         return;
       }
   
-  };  // void Angle_angle::Calculation()
+  }  // void Angle_angle::Calculation()
 
 
   //------------------------------------------------------------
@@ -527,9 +508,6 @@ namespace GaMaLib {
   void Circle::Calculation()
   {
     try {
-#ifdef PB_Debug
-      std::cout << "computing parameters of circle....\n";
-#endif
 
       number_of_solutions = 0;       // -1 when computation not done
       Double u = h1->value();	     // just to spare typing h1->value()
@@ -558,7 +536,7 @@ namespace GaMaLib {
         return;
       }
   
-  };  // void Circle::Calculation()
+  }  // void Circle::Calculation()
 
 } // namespace GaMaLib
 
