@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: network.cpp,v 1.13 2004/03/30 19:43:07 cepek Exp $
+ *  $Id: network.cpp,v 1.17 2004/09/01 11:59:45 cepek Exp $
  */
 
 #include <fstream>
@@ -33,7 +33,7 @@
 #include <gamalib/local/network.h>
 #include <gamalib/local/linearization.h>
 #include <gamalib/itstream.h>
-#include <gamalib/statan.h>
+#include <gnu_gama/statan.h>
 #include <gamalib/skipcomm.h>
 #include <gnu_gama/version.h>
 
@@ -127,8 +127,8 @@ void LocalNetwork::revision_observations()
   }
 
   // test cycle for StandPoint clusters with single direction
-  ClusterList& CL = OD.CL;
-  for (ClusterList::iterator cit=CL.begin(); cit!=CL.end(); ++cit)
+  ClusterList& clusters = OD.clusters;
+  for (ClusterList::iterator cit=clusters.begin(); cit!=clusters.end(); ++cit)
     {
       if (StandPoint* sp = dynamic_cast<StandPoint*>(*cit))
         {
@@ -163,8 +163,6 @@ void LocalNetwork::revision_observations()
       (*cit)->update();
     }
   
-  // RSM.erase(RSM.begin(), RSM.end());
-  // removed_obs.erase(removed_obs.begin(), removed_obs.end());
   RSM.clear();
   removed_obs.clear();
   for (ObservationData::iterator i=OD.begin(), e=OD.end(); i!=e; ++i)
@@ -196,8 +194,8 @@ void LocalNetwork::project_equations()
         }
     }
 
-  ClusterList& CL = OD.CL;
-  for (ClusterList::iterator cl=CL.begin(); cl!=CL.end(); ++cl)
+  ClusterList& clusters = OD.clusters;
+  for (ClusterList::iterator cl=clusters.begin(); cl!=clusters.end(); ++cl)
     if (StandPoint* standpoint=dynamic_cast<StandPoint*>(*cl))
       standpoint->index_orientation(0);
   
@@ -216,7 +214,7 @@ void LocalNetwork::project_equations()
     
     int  r = 0;
     pocet_neznamych_ = 0;
-    for (ObservationList::iterator m=RSM.begin(); m!=RSM.end(); ++m)
+    for (RevisedObsList::iterator m=RSM.begin(); m!=RSM.end(); ++m)
       {
         (*m)->linearization(&loclin);
         b(++r)  = loclin.rhs;
@@ -248,7 +246,8 @@ void LocalNetwork::project_equations()
   seznez_.resize(pocet_neznamych_);
   neznama_ nez;
   
-  for (ClusterList::iterator clptr=CL.begin(); clptr!=CL.end(); ++clptr)
+  for (ClusterList::iterator 
+         clptr=clusters.begin(); clptr!=clusters.end(); ++clptr)
     if (StandPoint* standpoint=dynamic_cast<StandPoint*>(*clptr))
       /*
        * in the following if (...) statement we test index of an orientation
@@ -493,12 +492,12 @@ Double LocalNetwork::conf_int_coef()
   
   Double pravdepodobnost = (1 - konf_pr_)/2;
   if (m_0_apriori())
-    return Normal(pravdepodobnost);
+    return GNU_gama::Normal(pravdepodobnost);
   else if (m_0_aposteriori())
     {
       const int nadb = degrees_of_freedom();
       if ( nadb > 0)
-        return Student(pravdepodobnost, nadb);
+        return GNU_gama::Student(pravdepodobnost, nadb);
       else
         return 0;
     }
@@ -601,7 +600,7 @@ void LocalNetwork::remove_huge_abs_terms()
   if (!huge_abs_terms()) return;
 
   Index r = 0;
-  for (ObservationList::iterator m = RSM.begin(); m!=RSM.end(); ++m)
+  for (RevisedObsList::iterator m = RSM.begin(); m!=RSM.end(); ++m)
     if (test_abs_term(++r))
       (*m)->set_passive();
   
@@ -735,7 +734,7 @@ void LocalNetwork::prepareProjectEquations()
   Index ind_0 = 0;
 
   for (ClusterList::const_iterator 
-         cluster=OD.CL.begin(); cluster!=OD.CL.end(); ++cluster)
+         cluster=OD.clusters.begin(); cluster!=OD.clusters.end(); ++cluster)
     if (const Index N = (*cluster)->activeObs())
         {
           Vec t(N);
@@ -838,7 +837,7 @@ void LocalNetwork::vyrovnani_()
     Index  ind_0 = 0;
     
     for (ClusterList::const_iterator 
-           cluster=OD.CL.begin(); cluster!=OD.CL.end(); ++cluster)
+           cluster=OD.clusters.begin(); cluster!=OD.clusters.end(); ++cluster)
       if (const Index N = (*cluster)->activeObs())
         {
           Vec t(N), u(N);
@@ -877,7 +876,7 @@ void LocalNetwork::vyrovnani_()
     Index ind_0 = 0;
 
     for (ClusterList::const_iterator 
-           cit=OD.CL.begin(); cit!=OD.CL.end(); ++cit)
+           cit=OD.clusters.begin(); cit!=OD.clusters.end(); ++cit)
       if (const Index N = (*cit)->activeObs())
         {
           const Cluster& cluster = *(*cit);
