@@ -1,4 +1,4 @@
-/*  
+/*
     Geodesy and Mapping C++ Library (GNU GaMa / GaMaLib)
     Copyright (C) 1999  Ales Cepek <cepek@fsv.cvut.cz>
 
@@ -20,19 +20,19 @@
 */
 
 /*
- *  $Id: error_ellipses.h,v 1.6 2004/03/18 17:07:01 cepek Exp $
+ *  $Id: error_ellipses.h,v 1.10 2004/06/20 20:54:51 cepek Exp $
  */
 
 #ifndef GaMa_GaMaProg_Prehled_Elipsy_Chyb_h_
 #define GaMa_GaMaProg_Prehled_Elipsy_Chyb_h_
 
 #include <gamalib/local/network.h>
-#include <gamalib/statan.h>
+#include <gnu_gama/statan.h>
 #include <cmath>
 
 namespace GaMaLib {
 
-template <class OutStream>
+template <typename OutStream>
 void ErrorEllipses(GaMaLib::LocalNetwork* IS, OutStream& out)
 {
    using namespace std;
@@ -47,7 +47,7 @@ void ErrorEllipses(GaMaLib::LocalNetwork* IS, OutStream& out)
      Double alfa = (1 - IS->conf_pr());
      if (IS->m_0_apriori())
        {
-	 elp_k = sqrt(GaMaLib::Chi_square(float(alfa), 2));
+	 elp_k = sqrt(GNU_gama::Chi_square(float(alfa), 2));
        }
      else
        {
@@ -132,10 +132,10 @@ void ErrorEllipses(GaMaLib::LocalNetwork* IS, OutStream& out)
                
                Double a, b, alfa;
                IS->std_error_ellipse(point_id, a, b, alfa);
-               if (y_sign == -1)
-                 {
-                   alfa = 2*M_PI - alfa;
-                 }
+               // if (y_sign == -1)
+               //   {
+               //     // 1.7.10 alfa = 2*M_PI - alfa;
+               //   }
                out.width(7);
                if (a < 1000)     
                  out.setf(ios_base::fixed, ios_base::floatfield);
