@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: fixed_points.h,v 1.4 2003/03/01 18:16:18 cepek Exp $
+ *  $Id: fixed_points.h,v 1.5 2004/06/20 20:54:51 cepek Exp $
  */
 
 #ifndef GaMa_GaMaProg_Pevne_Body_h_
@@ -32,7 +32,7 @@
 
 namespace GaMaLib {
 
-template <class OutStream>
+template <typename OutStream>
 void FixedPoints(GaMaLib::LocalNetwork* IS, OutStream& out)
 {
   using namespace std;
