@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: residuals_observations.h,v 1.7 2004/03/18 17:07:01 cepek Exp $
+ *  $Id: residuals_observations.h,v 1.10 2004/06/20 20:54:51 cepek Exp $
  */
 
 
@@ -28,14 +28,14 @@
 #define GaMa_GaMaProg_Opravy_Pozorovani__h_
 
 #include <gamalib/local/network.h>
-#include <gamalib/statan.h>
+#include <gnu_gama/statan.h>
 #include <algorithm>
 #include <typeinfo>
 
 static float ResidualsObservations_N01(float x)   // local helper function
 {
    double D, f;
-   GaMaLib::NormalDistribution(double(x), D, f);
+   GNU_gama::NormalDistribution(double(x), D, f);
    return D;
 }
 
@@ -64,7 +64,7 @@ public:
 
 namespace GaMaLib {
 
-template <class OutStream>
+template <typename OutStream>
 void ResidualsObservations(GaMaLib::LocalNetwork* IS, OutStream& out)
 {
   if(IS->degrees_of_freedom() <= 1) return; 
@@ -302,7 +302,8 @@ void ResidualsObservations(GaMaLib::LocalNetwork* IS, OutStream& out)
           for (int i=1; i<=pocmer; i++) pv(i) = (pv(i) - pvstr) / pvvar;
         
         float  ks, prob;
-        GaMaLib::KStest(pv.begin(), pocmer, ResidualsObservations_N01, ks, prob);
+        GNU_gama::KStest(pv.begin(), 
+                         pocmer, ResidualsObservations_N01, ks, prob);
         
         
         out.setf(ios_base::fixed, ios_base::floatfield);
