@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: observation.h,v 1.12 2004/01/17 21:36:14 cepek Exp $
+ *  $Id: observation.h,v 1.16 2004/09/02 12:54:13 cepek Exp $
  */
 
 #ifndef GaMaLib_Bod_Mer_Mereni_H
@@ -51,7 +51,8 @@ namespace GaMaLib {
   class Observation;
 
 
-  typedef GNU_gama::List<Observation*> ObservationList ;
+  typedef GNU_gama::List<Observation*> ObservationList;
+
   
   class Observation 
     {
@@ -108,6 +109,7 @@ namespace GaMaLib {
         }
 
       virtual void write(std::ostream&, bool print_at) const = 0;
+      static  bool gons;   // added in 1.7.09 
 
       // instrument / reflector height
 
@@ -118,6 +120,8 @@ namespace GaMaLib {
       void    set_from_dh(Double h) { from_dh_ = h; }
       void    set_to_dh  (Double h) { to_dh_   = h; }
 
+      int     dimension() const { return 1; }
+
     private:
     
       const PointID from_;
