@@ -1,6 +1,6 @@
 /*  
-    C++ Matrix/Vector templates (GNU Gama / gMatVec 0.9.22)
-    Copyright (C) 1999  Ales Cepek <cepek@fsv.cvut.cz>
+    C++ Matrix/Vector templates (GNU Gama / gMatVec 0.9.24)
+    Copyright (C) 1999  Ales Cepek <cepek@gnu.org>
 
     This file is part of the gMatVec C++ Matrix/Vector template library.
     
@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: array.h,v 1.10 2003/08/14 16:20:25 cepek Exp $
+ *  $Id: array.h,v 1.13 2004/08/30 18:18:55 cepek Exp $
  *  http://www.gnu.org/software/gama/
  */
 
@@ -31,17 +31,17 @@
 
 namespace gMatVec {
 
-template <class Type, class Exc=Exception>  
+template <typename Type, typename Exc=Exception>  
 class Array : public MemRep<Type, Exc> {
 
 public:
 
   Array(Index dim) : MemRep<Type, Exc>(dim) {}
-  Type  operator[](Index i) const { return begin()[i]; }
-  Type& entry(Index i) { return begin()[i]; }
+  Type  operator[](Index i) const { return this->begin()[i]; }
+  Type& entry(Index i) { return this->begin()[i]; }
   void swap(Index i, Index j) 
     {
-      Type *ind = begin();
+      Type *ind = this->begin();
       Type t = ind[i]; ind[i] = ind[j]; ind[j] = t; 
     }
 
