@@ -1,6 +1,6 @@
 /*  
-    C++ Matrix/Vector templates (GNU Gama / gMatVec 0.9.22)
-    Copyright (C) 2002  Ales Cepek <cepek@fsv.cvut.cz>
+    C++ Matrix/Vector templates (GNU Gama / gMatVec 0.9.24)
+    Copyright (C) 2002  Ales Cepek <cepek@gnu.org>
 
     This file is part of the gMatVec C++ Matrix/Vector template library.
     
@@ -20,12 +20,12 @@
 */
 
 /*
- *  $Id: bandmat2.h,v 1.4 2003/08/14 16:20:25 cepek Exp $
+ *  $Id: bandmat2.h,v 1.8 2004/08/30 18:18:55 cepek Exp $
  *  http://www.gnu.org/software/gama/
  */
 
-#ifndef gMatVec_Symmetric_Band_Matrix__H_
-#define gMatVec_Symmetric_Band_Matrix__H_
+#ifndef gMatVec_Symmetric_Band_Matrix_2__H_
+#define gMatVec_Symmetric_Band_Matrix_2__H_
 
 #include <gmatvec/gmatvec.h>
 #include <gmatvec/choldec.h>
@@ -49,7 +49,7 @@
 namespace gMatVec {
 
 
-template <class Float=double, class Exc=Exception>
+template <typename Float=double, typename Exc=Exception>
 class BandMat2 : public MatBase<Float, Exc>, public CholDec<Float, Exc> {
 public:
 
@@ -60,9 +60,13 @@ public:
   {
   }
   
-  void   reset() { row_=col_=band_=band_1=dim_b= 0; resize(0); }
+  void   reset() 
+  { 
+    this->row_ = this->col_ = band_ = band_1 = dim_b = 0; 
+    this->resize(0); 
+  }
   void   reset(Index d, Index b);
-  Index  dim() const { return row_; }
+  Index  dim() const { return this->row_; }
   Index  bandWidth() const { return band_; }
   Float  operator()(Index, Index) const; 
   Float& operator()(Index, Index);
@@ -72,7 +76,7 @@ public:
   
   const Float* operator[](Index row) const
   {
-    const Float* a_ = begin() + --row*band_1;
+    const Float* a_ = this->begin() + --row*band_1;
     if (row > dim_b) {
 	const Index i_  = row - dim_b;
 	a_ -= i_*(i_+1)/2;
@@ -81,7 +85,7 @@ public:
   }
   Float* operator[](Index row)
   {
-    Float* a_ = begin() + --row*band_1;
+    Float* a_ = this->begin() + --row*band_1;
     if (row > dim_b) {
       const Index i_  = row - dim_b;
       a_ -= i_*(i_+1)/2;
@@ -99,21 +103,21 @@ private:
 };      /* class BandMat2 */
   
 
-template <class Float, class Exc>
+template <typename Float, typename Exc>
 void BandMat2<Float, Exc>::reset(Index d, Index b)
 {
   if (dim() != d || band_ != b) 
     {
-      row_   = col_ = d;
+      this->row_ = this->col_ = d;
       band_  = b; 
       band_1 = b+1;
       dim_b  = d-b;	
-      resize(d*(b+1) - b*(b+1)/2);
+      this->resize(d*(b+1) - b*(b+1)/2);
     }
 }
 
 
-template <class Float, class Exc>
+template <typename Float, typename Exc>
 Float  BandMat2<Float, Exc>::operator()(Index r, Index s) const
 {
    if (r > s) {
@@ -129,7 +133,7 @@ Float  BandMat2<Float, Exc>::operator()(Index r, Index s) const
    return *(operator[](r) + s);
 }
 
-template <class Float, class Exc>
+template <typename Float, typename Exc>
 Float& BandMat2<Float, Exc>::operator()(Index r, Index s)
 {
    if (r > s) {
@@ -145,7 +149,7 @@ Float& BandMat2<Float, Exc>::operator()(Index r, Index s)
    return *(operator[](r) + s);
 }
 
-template <class Float, class Exc>
+template <typename Float, typename Exc>
 void BandMat2<Float, Exc>::cholDec()
 {
   /*
@@ -156,11 +160,11 @@ void BandMat2<Float, Exc>::cholDec()
    */
    using namespace std;
 
-   Float *B = begin();
+   Float *B = this->begin();
    Index  N = dim();
    Index  W = bandWidth();
 
-   const  Float  Tol = Abs(*B*cholTol());
+   const  Float  Tol = Abs(*B*this->cholTol());
    Float *p;
    Index  row, k, l, n;
    Float  pivot, q;
@@ -188,7 +192,7 @@ void BandMat2<Float, Exc>::cholDec()
      }
 }
 
-template <class Float, class Exc>
+template <typename Float, typename Exc>
 void BandMat2<Float, Exc>::solve(Vec<Float, Exc>& rhs) const
 {
   using namespace std;
@@ -218,7 +222,7 @@ void BandMat2<Float, Exc>::solve(Vec<Float, Exc>& rhs) const
 }
 
 
-template <class Float, class Exc>
+template <typename Float, typename Exc>
 Vec<Float, Exc> 
 BandMat2<Float, Exc>::operator*(const Vec<Float, Exc>& v) const
 {
@@ -244,14 +248,14 @@ BandMat2<Float, Exc>::operator*(const Vec<Float, Exc>& v) const
 }
 
 
-template <class Float, class Exc>
+template <typename Float, typename Exc>
 std::istream& BandMat2<Float, Exc>::read(std::istream& inp) 
 {
    int inpd, inpb;
    inp >> inpd >> inpb;
    reset(inpd, inpb);
  
-   Float  *b = begin();
+   Float  *b = this->begin();
    for (Index i=1; i<=dim(); i++)
       for (Index j=i; j<=i+band_; j++)
          if (j <= dim())
@@ -261,7 +265,7 @@ std::istream& BandMat2<Float, Exc>::read(std::istream& inp)
 }
 
 
-template <class Float, class Exc>
+template <typename Float, typename Exc>
 std::ostream& BandMat2<Float, Exc>::write(std::ostream& out) const
 {
    int w = out.width();
@@ -270,7 +274,7 @@ std::ostream& BandMat2<Float, Exc>::write(std::ostream& out) const
    out.width(w);
    out << band_ << "\n\n";
 
-   const Float  *b = begin();
+   const Float  *b = this->begin();
    for (Index i=1; i<=dim(); i++, out << '\n')
      for (Index j=i; j<=i+band_; j++)
        if (j <= dim()) 
