@@ -1,6 +1,6 @@
 /*
-    C++ Matrix/Vector templates (GNU Gama / gMatVec 0.9.22)
-    Copyright (C) 2000  Ales Cepek <cepek@fsv.cvut.cz>
+    C++ Matrix/Vector templates (GNU Gama / gMatVec 0.9.24)
+    Copyright (C) 2000  Ales Cepek <cepek@gnu.org>
 
     This file is part of the gMatVec C++ Matrix/Vector template library.
 
@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: hilbert.h,v 1.10 2003/08/14 16:20:25 cepek Exp $
+ *  $Id: hilbert.h,v 1.12 2004/08/30 18:18:55 cepek Exp $
  *  http://www.gnu.org/software/gama/
  */
 
@@ -31,7 +31,7 @@
 
 namespace gMatVec {
 
-template <class Float, class Exc> Mat<Float, Exc> InvHilbert(Index n)
+template <typename Float, typename Exc> Mat<Float, Exc> InvHilbert(Index n)
 {
   /* Inverse of a finite segment of the Hilbert matrix
    *
@@ -73,7 +73,7 @@ template <class Float, class Exc> Mat<Float, Exc> InvHilbert(Index n)
   return H;
 }
 
-template <class Float, class Exc> Mat<Float, Exc> Hilbert(Index n)
+template <typename Float, typename Exc> Mat<Float, Exc> Hilbert(Index n)
 {
   gMatVec::Mat<Float, Exc> H(n,n);
   const Float one = 1;
