@@ -1,6 +1,6 @@
 /*  
-    C++ Matrix/Vector templates (GNU Gama / gMatVec 0.9.22)
-    Copyright (C) 1999  Ales Cepek <cepek@fsv.cvut.cz>
+    C++ Matrix/Vector templates (GNU Gama / gMatVec 0.9.24)
+    Copyright (C) 1999  Ales Cepek <cepek@gnu.org>
 
     This file is part of the gMatVec C++ Matrix/Vector template library.
     
@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: mat.h,v 1.10 2003/08/14 16:20:25 cepek Exp $
+ *  $Id: mat.h,v 1.13 2004/08/30 18:18:55 cepek Exp $
  *  http://www.gnu.org/software/gama/
  */
 
@@ -34,9 +34,9 @@
 
 namespace gMatVec {
 
-template <class Float, class Exc> class TransMat;
+template <typename Float, typename Exc> class TransMat;
 
-template <class Float=double, class Exc=Exception> 
+template <typename Float=double, typename Exc=Exception> 
 class Mat : public MatBase<Float, Exc> {
 
 public:
@@ -50,8 +50,8 @@ public:
   Mat(Index r, Index c, Float m11 ...) : MatBase<Float, Exc>(r, c, r*c)
     {
       using namespace std;
-      iterator p=begin();
-      iterator e=end();
+      iterator p=this->begin();
+      iterator e=this->end();
       if (p == e)
         throw Exc(BadRank, "Mat::Mat(Index, Float ...)");
       *p = m11;  
@@ -68,30 +68,30 @@ public:
     }
 
   Float& operator()(Index r, Index c) {
-    Float *m = begin();
-    return m[--r*cols() + --c];
+    Float *m = this->begin();
+    return m[--r*this->cols() + --c];
   }
   Float  operator()(Index r, Index c) const {
-    const Float *m = begin();
-    return m[--r*cols() + --c];
+    const Float *m = this->begin();
+    return m[--r*this->cols() + --c];
   }
 
   Mat operator*(Float f) const { 
-    Mat t(rows(), cols()); mul(f, t); return t; 
+    Mat t(this->rows(), this->cols()); mul(f, t); return t; 
   }
   Mat operator+(const Mat& M) const { 
-    if (rows() != M.rows() || cols() != M.cols())
+    if (this->rows() != M.rows() || this->cols() != M.cols())
       throw Exc(BadRank, "Mat::operator+(const Mat& M) const");
     
-    Mat T(rows(), cols()); 
+    Mat T(this->rows(), this->cols()); 
     add(M, T); 
     return T; 
   }
   Mat operator-(const Mat& M) const { 
-    if (rows() != M.rows() || cols() != M.cols())
+    if (this->rows() != M.rows() || this->cols() != M.cols())
       throw Exc(BadRank, "Mat::operator-(const Mat& M) const");
     
-    Mat T(rows(), cols()); 
+    Mat T(this->rows(), this->cols()); 
     sub(M, T); 
     return T; 
   }
@@ -107,18 +107,18 @@ public:
 private:
 
 Float* pentry;  // not initialized in constructor !!!
-Float& entry(Index i, Index j) { return *(pentry + i*col_ + j); }
+Float& entry(Index i, Index j) { return *(pentry + i*this->col_ + j); }
 
 };
 
 
-template <class Float, class Exc>
+template <typename Float, typename Exc>
 inline Mat<Float, Exc> operator*(Float f, const Mat<Float, Exc> &M) {
   return M*f;
 }
 
 
-template <class Float, class Exc> 
+template <typename Float, typename Exc> 
 Mat<Float, Exc> 
 operator* (const MatBase<Float, Exc> &A, const MatBase<Float, Exc> &B)
   {
@@ -141,7 +141,7 @@ operator* (const MatBase<Float, Exc> &A, const MatBase<Float, Exc> &B)
   }
 
 
-template <class Float, class Exc>
+template <typename Float, typename Exc>
 Mat<Float, Exc> 
 operator+(const MatBase<Float, Exc> &A,const MatBase<Float, Exc> &B)
   {
@@ -157,7 +157,7 @@ operator+(const MatBase<Float, Exc> &A,const MatBase<Float, Exc> &B)
   }
 
 
-template <class Float, class Exc>
+template <typename Float, typename Exc>
 Mat<Float, Exc> 
 operator-(const MatBase<Float, Exc> &A, const MatBase<Float, Exc> &B)
   {
@@ -174,7 +174,7 @@ operator-(const MatBase<Float, Exc> &A, const MatBase<Float, Exc> &B)
 
 
 
-template <class Float, class Exc>
+template <typename Float, typename Exc>
 Mat<Float, Exc>
 operator*(const Mat<Float, Exc> &A, const Mat<Float, Exc> &B)
   {
@@ -204,17 +204,17 @@ operator*(const Mat<Float, Exc> &A, const Mat<Float, Exc> &B)
   }
 
 
-template <class Float, class Exc>
+template <typename Float, typename Exc>
 void Mat<Float, Exc>::invert()
 {
   /* Gauss-Jordan elimination */
 
-  if (row_ != col_)
+  if (this->rows() != this->cols())
     throw Exc(BadRank, "Mat<>::invert()");
 
-  pentry = begin();
+  pentry = this->begin();
 
-  const Index N = rows();
+  const Index N = this->rows();
   Index step, row, p_row, p_col, i, ii, j, jj, r, c, l;
 
   Array<Index> indr(N),indc(N);    // row/column permutation
@@ -310,7 +310,7 @@ void Mat<Float, Exc>::invert()
 }
 
 
-template <class Float, class Exc>
+template <typename Float, typename Exc>
 inline Mat<Float, Exc> inv(const Mat<Float, Exc>& A)
 {
   Mat<Float, Exc> t = A;
