@@ -1,6 +1,6 @@
 /*  
-    C++ Matrix/Vector templates (GNU Gama / gMatVec 0.9.22)
-    Copyright (C) 1999  Ales Cepek <cepek@fsv.cvut.cz>
+    C++ Matrix/Vector templates (GNU Gama / gMatVec 0.9.24)
+    Copyright (C) 1999  Ales Cepek <cepek@gnu.org>
 
     This file is part of the gMatVec C++ Matrix/Vector template library.
     
@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: transmat.h,v 1.10 2003/08/14 16:20:25 cepek Exp $
+ *  $Id: transmat.h,v 1.13 2004/08/30 18:18:55 cepek Exp $
  *  http://www.gnu.org/software/gama/
  */
 
@@ -36,7 +36,7 @@
 namespace gMatVec {
 
 
-template <class Float, class Exc> 
+template <typename Float, typename Exc> 
 class TransMat : public MatBase<Float, Exc> {
 
 public:
@@ -50,36 +50,36 @@ public:
     :  MatBase<Float, Exc>(M.cols(), M.rows(), M)  {}
 
   Float& operator()(Index r, Index c) {
-    Float *m = begin();
-    return m[--c*rows() + --r];
+    Float *m = this->begin();
+    return m[--c*this->rows() + --r];
   }
   Float  operator()(Index r, Index c) const {
-    const Float *m = begin();
-    return m[--c*rows() + --r];
+    const Float *m = this->begin();
+    return m[--c*this->rows() + --r];
   }
 
   void reset(Index r, Index c) {
-    if (r != row_ || c != col_) {
-      row_ = r; col_ = c; resize(r*c);
+    if (r != this->row_ || c != this->col_) {
+      this->row_ = r; this->col_ = c; this->resize(r*c);
     }
   }
 
   TransMat operator*(Float f) const { 
-    TransMat t(rows(), cols()); mul(f, t); return t; 
+    TransMat t(this->rows(), this->cols()); mul(f, t); return t; 
   }
   TransMat operator+(const TransMat& M) const { 
-    if (rows() != M.rows() || cols() != M.cols())
+    if (this->rows() != M.rows() || this->cols() != M.cols())
       throw Exc(BadRank, "TransMat operator+(const TransMat& M) const");
     
-    TransMat T(rows(), cols()); 
+    TransMat T(this->rows(), this->cols()); 
     add(M, T); 
     return T; 
   }
   TransMat operator-(const TransMat& M) const { 
-    if (rows() != M.rows() || cols() != M.cols())
+    if (this->rows() != M.rows() || this->cols() != M.cols())
       throw Exc(BadRank, "TransMat operator-(const TransMat& M) const");
     
-    TransMat T(rows(), cols()); 
+    TransMat T(this->rows(), this->cols()); 
     sub(M, T); 
     return T; 
   }
@@ -87,17 +87,17 @@ public:
 };
 
 
-template <class Float, class Exc>
+template <typename Float, typename Exc>
 inline TransMat<Float, Exc> operator*(Float f, const TransMat<Float, Exc> &M) {
   return M*f;
 }
 
 
-template <class Float, class Exc>
+template <typename Float, typename Exc>
 Mat<Float, Exc>::Mat(const TransMat<Float, Exc>& M)
   : MatBase<Float, Exc>(M.rows(), M.cols(), M.rows()*M.cols()) 
 {
-  iterator p=begin();
+  iterator p=this->begin();
   const Index R = M.rows();
   const Index C = M.cols();
   Index i, j;
@@ -107,13 +107,13 @@ Mat<Float, Exc>::Mat(const TransMat<Float, Exc>& M)
 }
 
 
-template <class Float, class Exc>
+template <typename Float, typename Exc>
 inline TransMat<Float, Exc> trans(const Mat<Float, Exc> &M) {
   return TransMat<Float, Exc>(M);
 }
 
 
-template <class Float, class Exc>
+template <typename Float, typename Exc>
 Mat<Float, Exc> trans(const TransMat<Float, Exc> &M) 
 {
   Mat<Float, Exc> T(M.cols(), M.rows());
@@ -128,7 +128,7 @@ Mat<Float, Exc> trans(const TransMat<Float, Exc> &M)
 }
 
 
-template <class Float, class Exc>
+template <typename Float, typename Exc>
 Mat<Float, Exc> 
 operator+(const Mat<Float, Exc> &A, const TransMat<Float, Exc> &B) 
   {
@@ -146,7 +146,7 @@ operator+(const Mat<Float, Exc> &A, const TransMat<Float, Exc> &B)
   }
 
 
-template <class Float, class Exc>
+template <typename Float, typename Exc>
 inline Mat<Float, Exc> 
 operator-(const Mat<Float, Exc> &A, const TransMat<Float, Exc> &B) 
   { 
@@ -164,7 +164,7 @@ operator-(const Mat<Float, Exc> &A, const TransMat<Float, Exc> &B)
   }
 
 
-template <class Float, class Exc>
+template <typename Float, typename Exc>
 inline Mat<Float, Exc> 
 operator+(const TransMat<Float, Exc> &A, const Mat<Float, Exc> &B) 
   {  
@@ -182,7 +182,7 @@ operator+(const TransMat<Float, Exc> &A, const Mat<Float, Exc> &B)
   }
 
 
-template <class Float, class Exc>
+template <typename Float, typename Exc>
 inline Mat<Float, Exc> 
 operator-(const TransMat<Float, Exc> &A, const Mat<Float, Exc> &B) 
   { 
@@ -200,7 +200,7 @@ operator-(const TransMat<Float, Exc> &A, const Mat<Float, Exc> &B)
   }
 
 
-template <class Float, class Exc>
+template <typename Float, typename Exc>
 Vec<Float, Exc> 
 operator*(const TransMat<Float, Exc> &A, const Vec<Float, Exc> &b)
   {
@@ -229,7 +229,7 @@ operator*(const TransMat<Float, Exc> &A, const Vec<Float, Exc> &b)
   }
 
 
-template <class Float, class Exc>
+template <typename Float, typename Exc>
 TransVec<Float, Exc> 
 operator*(const Vec<Float, Exc> &b, const TransMat<Float, Exc> &A)
   {
@@ -259,7 +259,7 @@ operator*(const Vec<Float, Exc> &b, const TransMat<Float, Exc> &A)
   }
 
 
-template <class Float, class Exc>
+template <typename Float, typename Exc>
 Mat<Float, Exc>
 operator*(const TransMat<Float, Exc> &A, const Mat<Float, Exc> &B)
   {
@@ -289,7 +289,7 @@ operator*(const TransMat<Float, Exc> &A, const Mat<Float, Exc> &B)
   }
 
 
-template <class Float, class Exc>
+template <typename Float, typename Exc>
 Mat<Float, Exc>
 operator*(const Mat<Float, Exc> &A, const TransMat<Float, Exc> &B)
   {
@@ -319,7 +319,7 @@ operator*(const Mat<Float, Exc> &A, const TransMat<Float, Exc> &B)
   }
 
 
-template <class Float, class Exc>
+template <typename Float, typename Exc>
 Mat<Float, Exc>
 operator*(const TransMat<Float, Exc> &A, const TransMat<Float, Exc> &B)
   {
