@@ -1,6 +1,6 @@
 /*  
-    C++ Matrix/Vector templates (GNU Gama / gMatVec 0.9.22)
-    Copyright (C) 1999  Ales Cepek <cepek@fsv.cvut.cz>
+    C++ Matrix/Vector templates (GNU Gama / gMatVec 0.9.24)
+    Copyright (C) 1999  Ales Cepek <cepek@gnu.org>
 
     This file is part of the gMatVec C++ Matrix/Vector template library.
     
@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: vec.h,v 1.10 2003/08/14 16:20:25 cepek Exp $
+ *  $Id: vec.h,v 1.13 2004/08/30 18:18:55 cepek Exp $
  *  http://www.gnu.org/software/gama/
  */
 
@@ -35,7 +35,7 @@
 namespace gMatVec {
   
 
-template <class Float=double, class Exc=Exception>
+template <typename Float=double, typename Exc=Exception>
 class Vec : public VecBase<Float, Exc> {
 
 public:
@@ -49,8 +49,8 @@ public:
   Vec(Index nsz, Float m11 ...) : VecBase<Float, Exc>(nsz)
     {
          using namespace std;
-         iterator p=begin();
-         iterator e=end();
+         iterator p=this->begin();
+         iterator e=this->end();
          if (p == e)
             throw Exc(BadRank, "Vec::Vec(Index, Float ...)");
          *p = m11;  
@@ -67,13 +67,13 @@ public:
     }
 
   Vec operator*(Float f) const { 
-    Vec t(dim()); mul(f, t); return t; 
+    Vec t(this->dim()); mul(f, t); return t; 
   }
   Vec operator+(const Vec &x) const {
-    Vec t(dim()); add(x, t); return t; 
+    Vec t(this->dim()); add(x, t); return t; 
   }
   Vec operator-(const Vec &x) const {
-    Vec t(dim()); sub(x, t); return t; 
+    Vec t(this->dim()); sub(x, t); return t; 
   }
 
   Vec& operator*=(Float f)      { mul(f, *this); return *this; }
@@ -88,14 +88,14 @@ public:
 };
 
 
-template <class Float, class Exc>
+template <typename Float, typename Exc>
 inline Vec<Float, Exc> operator*(Float f, const Vec<Float, Exc>& V)
   {
     return V*f;
   }
 
 
-template <class Float, class Exc>
+template <typename Float, typename Exc>
 Vec<Float, Exc> 
 operator*(const MatBase<Float, Exc> &A, const Vec<Float, Exc> &b)
   {
@@ -116,7 +116,7 @@ operator*(const MatBase<Float, Exc> &A, const Vec<Float, Exc> &b)
   }
 
 
-template <class Float, class Exc>
+template <typename Float, typename Exc>
 Vec<Float, Exc> 
 operator*(const Mat<Float, Exc> &A, const Vec<Float, Exc> &b)
   {
