@@ -1,6 +1,6 @@
 /*  
-    C++ Matrix/Vector templates (GNU Gama / gMatVec 0.9.22)
-    Copyright (C) 1999  Ales Cepek <cepek@fsv.cvut.cz>
+    C++ Matrix/Vector templates (GNU Gama / gMatVec 0.9.24)
+    Copyright (C) 1999  Ales Cepek <cepek@gnu.org>
 
     This file is part of the gMatVec C++ Matrix/Vector template library.
     
@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: vecbase.h,v 1.12 2003/08/14 16:20:25 cepek Exp $
+ *  $Id: vecbase.h,v 1.15 2004/08/30 18:18:55 cepek Exp $
  *  http://www.gnu.org/software/gama/
  */
 
@@ -35,7 +35,7 @@
 namespace gMatVec {
 
   
-template <class Float=double, class Exc=Exception>
+template <typename Float=double, typename Exc=Exception>
 class VecBase : public MatVecBase<Float, Exc> {
 
 protected:
@@ -48,16 +48,16 @@ public:
   typedef typename MatVecBase<Float, Exc>::iterator       iterator;
   typedef typename MatVecBase<Float, Exc>::const_iterator const_iterator;
 
-  Index dim() const { return size(); }
+  Index dim() const { return this->size(); }
 
   Float& operator()(Index n) { 
-    Float* m = begin(); return m[--n]; 
+    Float* m = this->begin(); return m[--n]; 
   }
   Float  operator()(Index n) const { 
-    const Float* m = begin(); return m[--n]; 
+    const Float* m = this->begin(); return m[--n]; 
   } 
 
-  void reset(Index n=0) { resize(n); }
+  void reset(Index n=0) { this->resize(n); }
 
   Float dot(const VecBase<Float, Exc> &B) const;
 
@@ -68,14 +68,14 @@ public:
 };
 
 
-template <class Float, class Exc>
+template <typename Float, typename Exc>
 Float VecBase<Float, Exc>::dot(const VecBase<Float, Exc> &B) const
   {
     if (dim() != B.dim())
       throw Exc(BadRank, "Float VecBase::dot(const VecBase&) const");
     
-    const_iterator a = begin();
-    const_iterator e = end();
+    const_iterator a = this->begin();
+    const_iterator e = this->end();
     const_iterator b = B.begin();
     
     Float sum = 0;
@@ -85,11 +85,11 @@ Float VecBase<Float, Exc>::dot(const VecBase<Float, Exc> &B) const
   }
 
 
-template <class Float, class Exc>
+template <typename Float, typename Exc>
 Float VecBase<Float, Exc>::norm_L1() const
   {
-    const_iterator a = begin();
-    const_iterator e = end();
+    const_iterator a = this->begin();
+    const_iterator e = this->end();
     
     Float sum = 0;
     while (a != e) { sum += *a >= 0 ? *a : -(*a); ++a; }
@@ -98,11 +98,11 @@ Float VecBase<Float, Exc>::norm_L1() const
   }
 
 
-template <class Float, class Exc>
+template <typename Float, typename Exc>
 Float VecBase<Float, Exc>::norm_Linf() const
   {
-    const_iterator a = begin();
-    const_iterator e = end();
+    const_iterator a = this->begin();
+    const_iterator e = this->end();
     
     Float norm = 0, x;
     while (a != e) 
@@ -116,7 +116,7 @@ Float VecBase<Float, Exc>::norm_Linf() const
   }
 
 
-template <class Float, class Exc>
+template <typename Float, typename Exc>
 std::istream& operator>>(std::istream& inp, VecBase<Float, Exc>& v)
   {
     Index size;
