@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: version.cpp,v 1.38 2004/05/01 13:56:40 cepek Exp $
+ *  $Id: version.cpp,v 1.51 2004/09/02 13:06:32 cepek Exp $
  */
 
 
@@ -28,13 +28,13 @@
 
 namespace GNU_gama {
 
-const char* GNU_gama_version  = "1.7.10";
+const char* GNU_gama_version  = "1.7.11";
 
 const char* GNU_gama_compiler =
               #if   defined (__GNUC__)
-              "GNU g++"             // g++ 3.0 / 3.3
-              #elif defined (__BORLANDC__) && (__linux__)
-              "kylix-bc++"          // 5.7
+              "GNU g++"             // g++ 3.3 / 3.4
+              // #elif defined (__BORLANDC__) && (__linux__)
+              // "kylix-bc++"          // 5.7
               #elif defined (__BORLANDC__)
               "win32-borland"       // 5.6
               #elif defined (_MSC_VER)
@@ -62,6 +62,46 @@ const char* GNU_gama_compiler =
 
 =============================================================================
 
+1.7.11 2004-09-02
+
+    - simplified version of GNU_gama::List<> template
+
+    - observation lists in gamalib/local/median rewritten to conform
+      the standard C++ library
+
+    - a lot of changes based on warnings reported by g++-3.4
+
+    - a bug in gkfparser.cpp reported by Jan Pytel
+
+            kwak$ diff gamalib/xml/gkfparser.cpp gkfparser.cpp.~1.16.~
+            58,59c58
+            <              state == state_vectors_cov ||
+            <              state == state_hdiffs_cov )
+            ---
+            >              state == state_vectors_cov )
+
+    - all occurrences of keyword 'class' in template type definitions
+      replaced by 'typeneme' (new gmatvec version 0.9.23)
+
+    - in the template class ObservationData (gnu_gama/obsdata.h) the
+      data member CL was renamed to 'clusters'
+
+    - first draft of zenith and azimuth angles in gama-g3 (NOT DEBUGGED YET!)
+
+    - gnu_gama/xml/dataparser.cpp split to three files dataparser.cpp,
+      dataparser_adj.cpp and dataparser_g3.cpp (corresponding to the
+      three functional modules)
+
+
+1.6.02 2004-05-20      ******  stable version 1.6  ******
+
+    - CVS tag gama-1-6 moved to point to the current development branch
+
+                        cvs tag -F gama-1-6
+
+                            **********************  
+
+
 1.7.10 2004-05-01
 
     - Catalan   translation of gama-local by Diego Berge
